import {
  select,
  descending,
  scaleBand,
  scaleLinear,
  max,
  axisLeft,
  axisBottom,
} from 'd3';
import { observeResize } from './observeResize';
import { axes } from './axes';
import { data } from '@216vignesh/4a3ee38d057a4c23a012efafcd71c3c5';
import { viz } from './viz';
export { xAxis } from './xAxis';
export { yAxis } from './yAxis';
export { xAxisLabel } from './xAxisLabel';
export { yAxisLabel } from './yAxisLabel';
export { axes } from './axes';
export { observeResize };
const no2LevelColumn = 'Data_Value';
const nameColumn = 'Geo_Place_Name';
data.forEach((d) => {
  d[no2LevelColumn] = +d[no2LevelColumn];
});
const filteredData = data.filter(
  (d) => !isNaN(d[no2LevelColumn]),
);
const n = 10;
const sortedData = filteredData
  .sort((a, b) =>
    descending(a[no2LevelColumn], b[no2LevelColumn]),
  )
  .slice(0, n);
export const main = (container, { state, setState }) => {
  const drawChart = () => {
    const { width, height } =
      container.getBoundingClientRect();

    const margin = {
      top: 50,
      right: 20,
      bottom: 100,
      left: 150,
    };
    const innerWidth = width - margin.left - margin.right;
    const innerHeight = height - margin.top - margin.bottom;
    const xScale = scaleBand()
      .domain(sortedData.map((d) => d[nameColumn]))
      .range([0, innerWidth])
      .padding(0.1);

    const yScale = scaleLinear()
      .domain([
        0,
        max(sortedData, (d) => d[no2LevelColumn]),
      ])
      .range([innerHeight, 0]);

    // Remove the old svg
    select(container).selectAll('svg').remove();
    console.log(width);
    console.log(height);
    // Create the svg element responsive to the container's size
    const svg = select(container)
      .append('svg')
      .attr('viewBox', `0 0 ${width} ${height}`)
      .append('g')
      .attr(
        'transform',
        `translate(${margin.left},${margin.top})`,
      );

    // Call the axes function to add the axes
    axes(svg, {
      width: innerWidth,
      height: innerHeight,
      xScale,
      yScale,
      xAxisLabelText: 'Geographical Area',
      yAxisLabelText: 'NO2 Level (ppb)',
      xAxisLabelOffset: 150,
      yAxisLabelOffset: -60,
      marginLeft: margin.left,
      marginBottom: margin.bottom,
    });
    svg
      .selectAll('.bar')
      .data(sortedData)
      .enter()
      .append('rect')
      // .attr('class', 'bar')
      .attr('x', (d) => xScale(d[nameColumn]))
      .attr('y', (d) => yScale(d[no2LevelColumn]))

      .attr(
        'height',
        (d) => innerHeight - yScale(d[no2LevelColumn]),
      )
      .attr('width', xScale.bandwidth())
      .attr('fill', 'steelblue');
  };

  drawChart();

  window.addEventListener('resize', drawChart);

  observeResize({
    state,
    setState,
    container,
    callback: drawChart,
  });
};
